@@ -272,3 +272,8 @@ test_that("translate sql server -> sqlite ALTER TABLE ADD COLUMN", {
   sql <- translate("ALTER TABLE my_table ADD COLUMN a INT;", targetDialect = "sqlite")
   expect_equal_ignore_spaces(sql, "ALTER TABLE my_table ADD COLUMN a INT;")
 })
+
+test_that("translate sql server -> sqlite ALTER TABLE ALTER COLUMN", {
+  sql <- translate("ALTER TABLE my_table ALTER COLUMN a BIGINT;", targetDialect = "sqlite")
+  expect_equal_ignore_spaces(sql, "SELECT 0;")
+})
